@@ -7,6 +7,8 @@ import smbus2
 import bme280
 import tabulate
 import os
+import pytz
+from email_handler import GMailAcc
 # from alert import AlertFactory
 
 DATA_FILE_NAME = 'data.txt'
@@ -17,7 +19,7 @@ class Controller:
     def __init__(self):
         self.alerts = list()
         self.bus_addrs = self.init_bus_vars()
-        self.check_bus()
+        # self.check_bus()
 
         self.bme_sensors = self.init_temp_sensors()
         self.ups = ups.DFR0528()
@@ -33,8 +35,13 @@ class Controller:
         self.batt_charge = None
         self.batt_capacity = self.ups.total_capacity
 
-    def update_status(self):
-        # todo send status email - delete old status email
+    def update_status(self, interval):
+        gmail_acc = GMailAcc()  # init gmail account
+
+        # send status email with Status as subject line, and response interval in seconds with s appended
+        email = gmail_acc.create_message(gmail_acc.address, gmail_acc.address, 'Status', interval + 's')
+        gmail_acc.send_message(gmail_acc.address, email)
+
         return
 
     def init_temp_sensors(self):
@@ -61,6 +68,7 @@ class Controller:
         # the sample method will take a single reading and return a
         # compensated_reading object
         data = bme280.sample(bus, addr, calibration_params)
+        bus.close()
 
         return data
 
@@ -127,7 +135,7 @@ class Controller:
         with open(DATA_FILEPATH, 'a') as data_file:
             # write header to file if empty
             if os.stat(DATA_FILEPATH).st_size == 0:
-                data_file.write(header_str)
+                data_file.write(header_str + '\n')
             data_file.write(x)
         data_file.close()
 
@@ -150,10 +158,11 @@ class Controller:
         """ process sensor inputs and ensure all are within limits """
 
         # desired limits set by user
-        temp_max_allowable = 0
-        humidity_max_allowable = 20
+        temp_max_allowable = 25
+        humidity_max_allowable = 80
 
         timestamp = datetime.datetime.now()
+        timestamp = timestamp.replace(tzinfo=pytz.timezone('Canada/Yukon'))
 
         # data processing
         self.T1 = self.bme_sensors['bme1'].temperature
@@ -173,7 +182,7 @@ class Controller:
             raise EnvError
 
         # STORAGE HEADER - timestamp, temp1, temp2, avg_temp, hum1, hum2, avg_hum, batt_capacity
-        to_store = [timestamp, self.T1, self.T2, self.TAvg, self.H1, self.H2, self.HAvg, self.batt_charge]
+        to_store = [timestamp, self.T1, self.T2, self.TAvg, self.H1, self.H2, self.HAvg, (self.batt_charge/self.batt_capacity)*100]
 
         return to_store
 
