@@ -12,15 +12,29 @@ from screen import Screen
 UPDATE_FREQ = 1
 
 
-def main():
-    try:
-        controller = Controller()
+def main(controller, screen=None):
+    x = 2
+    while x > 1:
+        try:
+            time.sleep(UPDATE_FREQ)
+            controller.update_controller()
+            controller.update_data_records(to_console=True)
+        except SensorError:
+            print("Sensor disconnected")
+            # todo send sensor disconnected message
+            pass
 
-        controller.update_controller()
-        controller.update_data_records(to_console=True)
+        except EnvError:
+            print("Environment Issue!")
+            # todo send env alert message
+            pass
+
+        except OSError:
+            print('Sensor disconnected!')
+            # todo send env alert message
+            pass
 
         try:
-            screen = Screen()
             lines = ['T1: {}C, T2: {}C'.format(round(controller.T1, 1), round(controller.T2, 1)),
                      'H1: {}%, H2: {}%'.format(round(controller.H1, 1), round(controller.H2, 1)),
                      'Battery: {}/{}'.format(controller.batt_charge, controller.batt_capacity)]
@@ -31,6 +45,20 @@ def main():
             # todo send screen disconnected message
             pass
 
+
+if __name__ == '__main__':
+    try:
+        controller = Controller()
+        try:
+            screen = Screen()
+            main(controller, screen)
+
+        except ValueError:
+            main(controller)
+            print("Screen disconnected")
+            # todo send screen disconnected message
+            pass
+
     except SensorError:
         print("Sensor disconnected")
         # todo send sensor disconnected message
@@ -42,8 +70,4 @@ def main():
         pass
 
 
-if __name__ == '__main__':
-    x = 2
-    while x > 1:
-        main()
-        time.sleep(UPDATE_FREQ)
\ No newline at end of file
+
